netapp_ontap.models.lun_space_guarantee API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_space_guarantee`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunSpaceGuaranteeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunSpaceGuarantee object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `requested GET POST PATCH`

    The requested space reservation policy for the LUN. If true, a space reservation is requested for the LUN; if false, the LUN is thin provisioned. Guaranteeing a space reservation request for a LUN requires that the volume in which the LUN resides is also space reserved and that the fractional reserve for the volume is 100%. Valid in POST and PATCH.

  `reserved GET`

    Reports if the LUN is space guaranteed.
    If true, a space guarantee is requested and the containing volume and aggregate support the request. If false, a space guarantee is not requested or a space guarantee is requested and either the containing volume or aggregate do not support the request.